@@ -1,8 +1,6 @@
 import asyncio
 import platform
 
-import nest_asyncio
-
 from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
 from .utils.Credential import Credential
 from .utils.Danmaku import Danmaku, DmFontSize, DmMode
@@ -13,9 +11,6 @@ from .utils.parse_link import parse_link
 
 HEADERS = {"User-Agent": "Mozilla/5.0", "Referer": "https://bilibili.com"}
 
-# 支持 asyncio 嵌套事件
-nest_asyncio.apply()
-
 # 如果系统为 Windows，则修改默认策略，以解决代理报错问题
 if "windows" in platform.system().lower():
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
@@ -25,31 +20,31 @@ __all__ = [
     "Danmaku",
     "DmFontSize",
     "DmMode",
-    "HEADERS", 
+    "HEADERS",
     "aid2bvid",
-    "app", 
+    "app",
     "article",
-    "bangumi", 
+    "bangumi",
     "bvid2aid",
-    "channel", 
-    "cheese", 
-    "comment", 
-    "dynamic", 
-    "favorite_list", 
+    "channel",
+    "cheese",
+    "comment",
+    "dynamic",
+    "favorite_list",
     "get_real_url",
     "get_session",
-    "homepage", 
-    "interactive_video", 
-    "live", 
+    "homepage",
+    "interactive_video",
+    "live",
     "login",
-    "parse_link", 
-    "rank", 
+    "parse_link",
+    "rank",
     "search",
     "set_session",
-    "settings", 
-    "sync", 
-    "user", 
-    "video_uploader", 
-    "video", 
-    "vote"
+    "settings",
+    "sync",
+    "user",
+    "video_uploader",
+    "video",
+    "vote",
 ]
